@@ -123,13 +123,10 @@ class EquivariantAttention(nn.Module):
             Rearrange('... () -> ...')
         )
 
-        last_coors_linear = nn.Linear(m_dim * 4, 1)
-        last_coors_linear.weight.data.zero_()
-
         self.coors_mlp = nn.Sequential(
             nn.Linear(m_dim, m_dim * 4),
             nn.ReLU(),
-            last_coors_linear,
+            nn.Linear(m_dim * 4, 1),
             Rearrange('... () -> ...'),
             nn.TanH() if norm_coor_weights else nn.Identity()
         )
